.. :changelog:

History
=======

0.2.2
-----

* Fix Django version compatibility. Django 1.5 not supported anymore.

0.2.1
-----

* Username as default if not first and last name defined

0.1.4
-----

* Serveral fixes and updated doc

0.1.0
-----

* Initial application
